@@ -107,11 +107,15 @@ GHashTable * atspi_text_get_default_attributes (AtspiText *obj, GError **error);
 
 gboolean atspi_text_set_caret_offset (AtspiText *obj, gint new_offset, GError **error);
 
+#ifndef ATSPI_DISABLE_DEPRECATED
 AtspiTextRange * atspi_text_get_text_before_offset (AtspiText *obj, gint offset, AtspiTextBoundaryType type, GError **error);
 
 AtspiTextRange * atspi_text_get_text_at_offset (AtspiText *obj, gint offset, AtspiTextBoundaryType type, GError **error);
 
 AtspiTextRange * atspi_text_get_text_after_offset (AtspiText *obj, gint offset, AtspiTextBoundaryType type, GError **error);
+#endif
+
+AtspiTextRange * atspi_text_get_string_at_offset (AtspiText *obj, gint offset, AtspiTextGranularity granularity, GError **error);
 
 guint atspi_text_get_character_at_offset (AtspiText *obj, gint offset, GError **error);
 
@@ -133,6 +137,11 @@ gboolean atspi_text_remove_selection (AtspiText *obj, gint selection_num, GError
 
 gboolean atspi_text_set_selection (AtspiText *obj, gint selection_num, gint start_offset, gint end_offset, GError **error);
 
+gboolean atspi_text_scroll_substring_to (AtspiText *obj, gint start_offset, gint end_offset, AtspiScrollType type, GError **error);
+
+gboolean atspi_text_scroll_substring_to_point (AtspiText *obj, gint start_offset, gint end_offset, AtspiCoordType coords, gint x, gint y, GError **error);
+
+void atspi_text_notify_reading_position (AtspiText *obj, gint startOffset, gint endOffset);
 G_END_DECLS
 
 #endif	/* _ATSPI_TEXT_H_ */
